"use client";

import { useState } from "react";
import { useRouter } from "next/navigation";
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import { Search, SlidersHorizontal } from "lucide-react";
import { useDebounce } from "use-debounce";
import SearchSuggestions from "./SearchSuggestions";

interface SearchHeaderProps {
  onToggleFilters: () => void;
}

export default function SearchHeader({ onToggleFilters }: SearchHeaderProps) {
  const router = useRouter();
  const [query, setQuery] = useState("");
  const [showSuggestions, setShowSuggestions] = useState(false);
  const [debouncedQuery] = useDebounce(query, 300);

  const handleSearch = (searchQuery: string) => {
    const params = new URLSearchParams();
    if (searchQuery) params.set("q", searchQuery);
    router.push(`/search?${params.toString()}`);
    setShowSuggestions(false);
  };

  return (
    <header className="sticky top-0 z-50 border-b bg-background/95 backdrop-blur supports-[backdrop-filter]:bg-background/60">
      <div className="container mx-auto px-4 h-16">
        <div className="flex items-center justify-between h-full gap-4">
          <div className="flex-1 max-w-2xl relative">
            <div className="relative">
              <Search className="absolute left-3 top-1/2 transform -translate-y-1/2 h-4 w-4 text-muted-foreground" />
              <Input
                type="text"
                placeholder="Search schools, programs, or locations..."
                value={query}
                onChange={(e) => {
                  setQuery(e.target.value);
                  setShowSuggestions(true);
                }}
                onKeyDown={(e) => {
                  if (e.key === "Enter") handleSearch(query);
                }}
                className="pl-10"
              />
            </div>
            {showSuggestions && debouncedQuery && (
              <SearchSuggestions
                query={debouncedQuery}
                onSelect={(suggestion) => {
                  setQuery(suggestion);
                  handleSearch(suggestion);
                }}
              />
            )}
          </div>
          <div className="flex items-center gap-4">
            <Button
              variant="outline"
              size="icon"
              onClick={onToggleFilters}
              className="lg:hidden"
            >
              <SlidersHorizontal className="h-4 w-4" />
            </Button>
            <Button onClick={() => handleSearch(query)}>
              Search Schools
            </Button>
          </div>
        </div>
      </div>
    </header>
  );
}